@@ -18,7 +18,7 @@ from octavia_lib.api.drivers import exceptions
 # Load balancing provider drivers will implement this interface.
 
 
-class ProviderDriver(object):
+class ProviderDriver():
     # name is for internal Octavia use and should not be used by drivers
     name = None
 
@@ -487,6 +487,7 @@ class ProviderDriver(object):
         :raises NotImplementedError: The driver does not support flavors.
         :raises UnsupportedOptionError: if driver does not
           support one of the configuration options.
+        :raises NotFound: if the driver cannot find a resource.
         """
         raise exceptions.NotImplementedError(
             user_fault_string='This provider does not support validating '
@@ -503,7 +504,7 @@ class ProviderDriver(object):
 
         :returns: The availability zone metadata dictionary
         :raises DriverError: An unexpected error occurred in the driver.
-        :raises NotImplementedError: The driver does not support flavors.
+        :raises NotImplementedError: The driver does not support AZs.
         """
         raise exceptions.NotImplementedError(
             user_fault_string='This provider does not support getting the '
@@ -511,7 +512,7 @@ class ProviderDriver(object):
             operator_fault_string='This provider does not support getting '
                                   'the supported availability zone metadata.')
 
-    def validate_availability_zone(self, flavor_metadata):
+    def validate_availability_zone(self, availability_zone_metadata):
         """Validates if driver can support the availability zone.
 
         :param availability_zone_metadata: Dictionary with az metadata.
